@@ -369,7 +369,8 @@ class AdHocAction(PythonAction):
             self.action_spec.get_base()
         )
         base_action_def = self._gather_base_actions(
-            action_def, base_action_def
+            action_def,
+            base_action_def
         )
 
         super(AdHocAction, self).__init__(
@@ -409,11 +410,17 @@ class AdHocAction(PythonAction):
             base_input_expr = action_spec.get_base_input()
 
             if base_input_expr:
+                wf_ex = (
+                    self.task_ex.workflow_execution if self.task_ex else None
+                )
+
                 ctx_view = data_flow.ContextView(
                     base_input_dict,
                     self.task_ctx,
+                    data_flow.get_workflow_environment_dict(wf_ex),
                     self.wf_ctx
                 )
+
                 base_input_dict = expr.evaluate_recursively(
                     base_input_expr,
                     ctx_view
@@ -435,8 +442,10 @@ class AdHocAction(PythonAction):
 
                 if transformer is not None:
                     result = ml_actions.Result(
-                        data=expr.evaluate_recursively(transformer,
-                                                       result.data),
+                        data=expr.evaluate_recursively(
+                            transformer,
+                            result.data
+                        ),
                         error=result.error
                     )
 
@@ -538,10 +547,6 @@ class WorkflowAction(Action):
             'namespace': parent_wf_ex.params['namespace']
         }
 
-        if 'env' in parent_wf_ex.params:
-            wf_params['env'] = parent_wf_ex.params['env']
-            wf_params['evaluate_env'] = parent_wf_ex.params.get('evaluate_env')
-
         for k, v in list(input_dict.items()):
             if k not in wf_spec.get_input():
                 wf_params[k] = v
